/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Calendar **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:41+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Italian (http://www.transifex.com/tine20/tine20/language/it/)\nLanguage: it\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "{0}, the {1}. of {2}"
: "{0}, il {1}. di {2}"

, "Recurrances"
: "Ricorrenze"

, "No recurring rule defined"
: "Nessuna regola ricorrente definita"

, "Details"
: "Dettagli"

, "None"
: "Nessuno"

, "Daily"
: "Quotidiano"

, "Weekly"
: "Settimanale"

, "Monthly"
: "Mensile"

, "Yearly"
: "Annuale"

, "Exceptions of reccuring events can't have recurrences themselves."
: "Eccezioni di eventi che si ripetono non possono ripertersi su se stessi."

, "at"
: "a"

, "never"
: "mai"

, "after {0} occurrences"
: "dopo {0} occorrenze"

, "Except"
: ""

, "during events in the calendars"
: ""

, "End"
: "Fine"

, "Until has to be after event start"
: "Fino a deve essere successivo alla data di inizio dell'evento"

, "The event is longer than the recurring interval"
: ""

, "Every {0}. Day"
: "Ogni {0}. Giornalmente"

, "Every {0}. Week at"
: "Ogni {0}. Settimanalmente"

, "Every {0}. Month"
: "Ogni {0}. Mensilmente"

, "at the"
: "a"

, "first"
: "primo"

, "second"
: "secondo"

, "third"
: "terzo"

, "fourth"
: "quarto"

, "last"
: "ultimo"

, "Every {0}. Year"
: "Ogni {0}. Annualmente"

, "of"
: "di"

, "Summary"
: "Sommario"

, "Organizer"
: "Organizzatore"

, "Description"
: "Descrizione"

, "Location"
: "Luogo"

, "Start Time"
: "Ora di inizio"

, "End Time"
: "Ora di fine"

, "Attendee"
: "Partecipante"

, "whole day"
: "giorno intero"

, "Week {0} :"
: "Settimana {0} :"

, "Poll, Polls"
: [
  ""
 ,""

]
, "Options"
: ""

, "Alternative Dates"
: ""

, "Set as definite event"
: ""

, "Create Poll for this Event"
: ""

, "Name for poll"
: ""

, "Create scheduling suggestions and pick the best alternative based on user feedback."
: ""

, "Share the link below to poll for attendee status feedback."
: ""

, "Public URL"
: ""

, "Protect poll with a password"
: ""

, "Only invited attendee can reply"
: ""

, "Start Date"
: ""

, "Info"
: ""

, "loading alternative dates"
: ""

, "Select one Event Only"
: ""

, "You need to select exactly one event as the definite event."
: ""

, "Setting definite event"
: ""

, "New Event"
: "Nuovo Evento"

, "Calendar, Calendars"
: [
  "Calendario"
 ,"Calendari"

]
, "Event not found"
: ""

, "The Event was deleted in the meantime or you don't have access rights to it."
: ""

, "Switch to public poll"
: ""

, "Welcome {name}"
: ""

, "This is a closed poll. No Attendee can be added."
: ""

, "This poll is closed already"
: ""

, "I am not {name}"
: ""

, "Login"
: ""

, "{headerDate, date, full} {headerDate, time, short}"
: ""

, "Cancel"
: ""

, "Save"
: ""

, "By using this service you agree to our terms and conditions"
: ""

, "Use your personal link please."
: ""

, "We have sent it to your E-Mail account again."
: ""

, "If you did not receive the link, please contact the organiser."
: ""

, "Password"
: ""

, "Submit"
: ""

, "Wrong password!"
: ""

, "Please log in"
: ""

, "User name"
: ""

, "Calendar of {name}"
: ""

, "An unexpected error occurred."
: ""

, "Add attendee"
: "Aggiungi partecipante"

, "Sort Attendee"
: "Ordina partecipanti"

, "Check to filter for this attendee"
: "Spuntare per filtrare per questo partecipante"

, "Unavailable"
: ""

, "Loading events, please wait..."
: "Eventi in modifica, per favore attendi..."

, "Cut event"
: ""

, "Copy Event to clipboard"
: ""

, "Stop cut / copy & paste"
: ""

, "Print Page"
: "Stampa Pagina"

, "Loose-Leaf"
: ""

, "Sheet"
: "Foglio"

, "Grid"
: "Griglia"

, "Timeline"
: ""

, "Day"
: "Giorno"

, "Week"
: "Settimana"

, "Month"
: "Mese"

, "Year"
: ""

, "Custom Selection"
: ""

, "Import Events"
: ""

, "Paste event \"{0}\""
: ""

, "Set my response"
: "Imposta la mia risposta"

, "Copy {0}"
: "Copia {0}"

, "Set event status"
: ""

, "Updating event in the past"
: "Aggiornamento evento passato"

, "Update this event"
: "Aggiorna questo evento"

, "Do not update this event"
: "Non aggiornare questo evento"

, "Creating event in the past"
: "Creazione di eventi nel passato"

, "Create this event"
: "Crea questo evento"

, "Do not create this event"
: "Non creare questo evento"

, "Update this event only"
: "Aggiorna solamente questo evento"

, "Update this and all future events"
: "Aggiorna questo e tutti gli eventi futuri"

, "Update whole series"
: "Aggiorna l'intera serie"

, "Update nothing"
: "Non aggiorna niente"

, "Update Event"
: "Aggiorna Evento"

, "Please Change Selection"
: "Per favore cambia la selezione"

, "Your selection contains recurring events. Recuring events must be deleted seperatly!"
: "La tua selezione contiene eventi ricorrenti. Gli eventi ricorrenti devono essere cancellati separatamente!"

, "Delete Event"
: "Cancella Evento"

, "Delete this event only"
: "Cancella solamente questo evento"

, "Delete this and all future events"
: "Cancella questo e tutti gli eventi futuri"

, "Delete whole series"
: "Cancella tutte le serie"

, "Delete nothing"
: "Eliminare niente"

, "Do you really want to delete this event?, Do you really want to delete the {0} selected events?"
: [
  "Vuoi veramente cancellare questo evento?"
 ,"Vuoi veramente cancellare i {0} eventi selezionati?"

]
, "Could not Print"
: "Potrebbe non Stampare"

, "Sorry, your current view does not support printing."
: "Spiacenti, la tua visualizzazione corrente non supporta la stampa."

, "Scheduling Conflict"
: "Conflitto di Schedulazione"

, "The following attendee are busy at the requested time:"
: "I seguenti partecipanti sono occupati per il tempo specificato:"

, "Ignore Conflict"
: "Ignora Conflitto"

, "Edit Event"
: "Modifica Evento"

, "Cancel this action"
: "Annulla questa azione"

, "Update Status for all Attendee?"
: ""

, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
: ""

, "Manage Resources"
: "Gestisci risorse"

, "GENDER_Attendee"
: ""

, "Select Attendee"
: "Seleziona Partecipante"

, "Attachments"
: ""

, "Private"
: "Privato"

, "Tags"
: "Tags"

, "Blocking"
: "Bloccante"

, "Tentative"
: "Tentativo"

, "Import Definition Success!"
: ""

, "The Ical Import definition has been created successfully! Please wait some minutes to get the events synced by the cronjob."
: ""

, "Choose Import File"
: ""

, "Please choose the file that contains the records you want to add to Tine 2.0"
: ""

, "Select file containing your {0}"
: ""

, "once"
: ""

, "hourly"
: ""

, "daily"
: ""

, "weekly"
: ""

, "Choose Remote Location"
: ""

, "Please choose a remote location you want to add to Tine 2.0"
: ""

, "Username"
: ""

, "Refresh time"
: ""

, "General Settings"
: ""

, "Calendar name (you need permissions to add events)"
: ""

, "What should the file you upload look like?"
: ""

, "Tine 2.0 does not understand all kind of files you might want to upload. You will have to manually adjust your file so Tine 2.0 can handle it."
: ""

, "Following you find a list of all supported import formats and a sample file, how Tine 2.0 expects your file to look like."
: ""

, "Please select the import format of the file you want to upload"
: ""

, "Download example file"
: ""

, "Remote / ICS"
: ""

, "Remote / CalDAV (BETA)"
: ""

, "Upload"
: ""

, "Choose File and Format"
: ""

, "Select type of source"
: ""

, "Please select the type of source you want to add to Tine 2.0"
: ""

, "Importing {0}"
: ""

, "Back"
: ""

, "Next"
: ""

, "Ok"
: ""

, "Free Time Search"
: ""

, "Searching for Free Time..."
: ""

, "No Free Time found"
: ""

, "No free timeslot could be found Until {0}. Do you want to continue?"
: ""

, "Continue"
: ""

, "Give up"
: ""

, "Free Time Search Options"
: ""

, "private classification"
: "Classificazione privata"

, "recurring event"
: "evento ricorrente"

, "recurring event exception"
: "eccezione di evento ricorrente"

, "has alarm"
: "è allarme"

, "has attachments"
: "ha allegati"

, "is part of an open poll"
: ""

, "Mini Calendar"
: "Mini Calendario"

, "WK"
: "SE"

, "{0} more..."
: "{0} o più..."

, "Resource Grant, Resource Grants"
: [
  ""
 ,""

]
, "Invite Resource"
: ""

, "The grant to invite the resource to an event"
: ""

, "Read Resource"
: ""

, "The grant to read the resource itself"
: ""

, "Edit Resource"
: ""

, "The grant to edit the resource itself"
: ""

, "Export Resource"
: ""

, "The grant to export the resource itself"
: ""

, "Sync Resource"
: ""

, "The grant to synchronise the resource itself"
: ""

, "Resource Admin"
: ""

, "The grant to administrate the resource itself"
: ""

, "Add Events"
: ""

, "The grant to directly add events into this resource calendar"
: ""

, "Read Events"
: ""

, "The grant to read events from this resource calendar"
: ""

, "Export Events"
: ""

, "The grant to export events from this resource calendar"
: ""

, "Sync Events"
: ""

, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
: ""

, "Events Free Busy"
: ""

, "The grant to get free/busy information of events from this resource calendar"
: ""

, "Edit Events"
: ""

, "The grant to respond to event invitations of this resource and to edit events directly saved in this resource calendar"
: ""

, "Delete Events"
: ""

, "The grant to delete events directly stored in this resource calendar"
: ""

, "Free Busy"
: ""

, "The grant to get free/busy information of events in this calendar"
: ""

, "The grant to access events marked as private in this calendar"
: ""

, "Rrule"
: ""

, "Please choose the Event to add the contacts to"
: "Si prega di scegliere l'evento da aggiungere ai contatti"

, "Role"
: "Ruolo"

, "Select Role"
: "Seleziona Ruolo"

, "Status"
: "Stato"

, "Select Status"
: "Seleziona Stato"

, "Adding {0} Attendee to event"
: "Aggiunti {0} Partecipanti all'evento"

, "no events found"
: "nessun evento trovato"

, "Searching..."
: "Ricerca..."

, "Search Event"
: "Cerca Evento"

, "Event, Events"
: [
  "Evento"
 ,"Eventi"

]
, "Additional Tags ..."
: ""

, "non-blocking"
: "non-bloccante"

, "Displayed in"
: "Visualizzato in"

, "No Information"
: "Nessuna informazione"

, "Event Location"
: ""

, "From"
: ""

, "until"
: ""

, "Events"
: "Eventi"

, "Calendars"
: "Calendari"

, "Quick Search"
: "Ricerca veloce"

, "GENDER_Calendar"
: ""

, "Attendee Status"
: "Stato Partecipante"

, "GENDER_Attendee Status"
: ""

, "Attendee Role"
: "Ruolo partecipante"

, "GENDER_Attendee Role"
: ""

, "GENDER_Status"
: ""

, "GENDER_Blocking"
: ""

, "Classification"
: "Classificazione"

, "GENDER_Classification"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Unknown date"
: ""

, "{0} {1} o'clock"
: "{0} {1} in punto"

, "Event (as attendee)"
: "Evento (come partecipante)"

, "Event (as organizer)"
: "Evento (come organizzatore)"

, "Event attendee"
: "Evento partecipante"

, "Attender, Attendee"
: [
  "Partecipante"
 ,"Partecipanti"

]
, "Resource, Resources"
: [
  "Risorsa"
 ,"Risorse"

]
, "Resources"
: "Risorse"

, "Anyone"
: ""

, "Name"
: "Nome"

, "Calendar Hierarchy/Name"
: ""

, "Email"
: "Email"

, "Maximum number of attendee"
: ""

, "Type"
: "Tipo"

, "Default attendee status"
: ""

, "Busy Type"
: ""

, "Event finder options"
: ""

, "Click here to invite another attender..."
: "Clicca qui per invitare un altro partecipante..."

, "User"
: "Utente"

, "Group"
: "Gruppo"

, "Member of group"
: "Membro del gruppo"

, "This is the calendar where the attender has saved this event in"
: "Questo è il calendario in cui il partecipante ha salvato l'evento"

, "Click icon to change"
: ""

, "Availability of Attendee"
: ""

, "Whole Group or each Member of Group"
: ""

, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
: ""

, "Member of Group"
: ""

, "Loading Groupmembers..."
: ""

, "Remove Attender"
: "Rimuovi partecipante"

, "Compose email"
: ""

, "Poll URL: {0}"
: ""

, "View Resource"
: ""

, "(as a group member)"
: "(come membro del gruppo)"

, "External Attendee"
: "Partecipante Esterno"

, "Originally"
: "Originariamente"

, "Checking Calendar Data..."
: "Verifica Dati Calendario ..."

, "Reply to Recurring Event"
: "Rispondi a Evento Ricorrente"

, "You are responding to an recurring event. What would you like to do?"
: "Stai rispondendo ad un evento ricorrente. Cosa desideri fare?"

, "Respond to whole series"
: "Rispondi all'intera serie"

, "Do not respond"
: "Non rispondere"

, "The event of this message does not exist"
: "L'evento di questo messaggio non esiste"

, "The sender is not authorised to update the event"
: "Il mittente non è autorizzato ad aggiornare l'evento"

, "This message is already processed"
: "Questo messaggio è già stato elaborato"

, "You are not an attendee of this event"
: "Non sei un partecipante di questo evento"

, "This event has been deleted by the organizer"
: ""

, "This event has been canceled."
: ""

, "Unsupported message"
: "messaggio non supportato"

, "This is an event invitation for someone else."
: "Questo è un invito per l'evento per qualcun altro."

, "You have already replied to this event invitation."
: "Hai già risposto a questo invito per l'evento."

, "The event got rescheduled. Set your response to:"
: ""

, "You received an event invitation. Set your response to:"
: "Hai ricevuto un invito per un evento. Imposta la risposta a:"

, "An invited attendee responded to the invitation."
: "Un partecipante invitato ha risposto all'invito."

, "Unsupported method"
: "Metodo non supportato"

, "Suppress notification"
: ""

, "Color"
: ""

, "Enter description..."
: "Inserisci descrizione..."

, "Grants"
: "Permessi"

, "This event is originally stored in a calendar you don't have access to."
: "Questo evento è originariamente memorizzato in un calendario di cui non hai accesso."

, "This event is originally stored in {0}"
: "Questo evento è originariamente memorizzato in {0}"

, "This event is additionally displayed in your personal calendar {0}"
: "Questo evento è inoltre visualizzato nel calendario personale {0}"

, "Colors"
: ""

, "Side bar color"
: ""

, "Color by Calendar"
: ""

, "Color by Attendee Calendar"
: ""

, "Color by Tags"
: ""

, "Color by Attendee Role"
: ""

, "Colors by response"
: ""

, "Colors by tags"
: ""

, "Colors by attendee"
: ""

, "Colors by resource"
: ""

, "View"
: "Visualizza"

, "Saved in"
: "Salvato in"

, "Enter description"
: "Inserisci descrizione"

, "Notifications are disabled"
: ""

, "Notifications are enabled"
: ""

, "Print Event"
: ""

, "Send Notification?"
: ""

, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
: ""

, "End date is not valid"
: "La data di fine non è valida"

, "End date must be after start date"
: "La data di fine deve essere successiva della data di inizio"

, "End time is not allowed to be after the configured time."
: ""

, "Start date is not valid"
: "La data di inizio non è valida"

, "Start date is not allowed to be before the configured time."
: ""

, "The summary must not be longer than 255 characters."
: "l riepilogo non deve essere più lungo di 255 caratteri."

, "The summary must have at least 1 character."
: "Il riepilogo deve contenere almeno 1 carattere."

, "Summary too Long"
: "Sommario troppo lungo"

, "Summary too Short"
: "Sommario troppo corto"

, "Set This Date as Definite Event?"
: ""

, "Do you want to close the poll and remove all other alternatives?"
: ""

, "Attendee/Resources"
: ""

, "Additional Attendees ..."
: ""

, "Default Status"
: ""

, "No Access"
: ""

, "All my events"
: "Tutti miei eventi"

, "Position on the left time axis, day and week view should start with"
: "Posizione sull'asse del tempo a sinistra, giorno e settimana dovrebbero iniziare con"

, "Position on the left time axis, day and week view should end with"
: ""

, "Default Start Time"
: ""

, "Scroll position on the left time axis, day and week view should start with"
: ""

, "Visible Time"
: ""

, "Time to be displayed at once"
: ""

, "Default Calendar"
: "Calendario di default"

, "The default calendar for invitations and new events"
: "Il calendario di default per gli inviti e i nuovi eventi"

, "Default Favorite"
: "Preferiti predefiniti"

, "The default favorite which is loaded on calendar startup"
: "Il preferito di default che è caricato all'apertura del calendario"

, "Get Notification Emails"
: "Prendi le email di notifica"

, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
: "I livelli di azione per cui vuoi essere notificato. Attenzione che gli organizzatori riceveranno notifiche per tutti gli aggiornamenti includendo le risposte dei partecipanti a meno che tale impostazione sia impostata a \"Mai\""

, "Send Notifications Emails of own Actions"
: "Invia Notifiche Email per le tue Azioni"

, "Get notifications emails for actions you did yourself"
: "Ricevi notifiche email per le azioni compiute da te stesso"

, "Send Notifications Emails of tentative events"
: ""

, "Get notifications emails of tentative events"
: ""

, "Send Alarm Notifications Emails"
: ""

, "Get event alarms via email"
: ""

, "Enable Standard Alarm"
: "Attiva Avviso Standard"

, "New events get a standard alarm as defined below"
: "I nuovi eventi hanno un avviso standard come definito di seguito"

, "Standard Alarm Time"
: "Orario Avviso Standard"

, "Minutes before the event starts"
: "Minuti prima dell'inizio dell'evento"

, "Default Attendee Strategy"
: ""

, "Default Attendee Strategy for new events"
: ""

, "Time Increment"
: ""

, "Increment of event time steps"
: ""

, "Default set Events to privat"
: ""

, "If enabled every created event is always privat"
: ""

, "First Day of Week"
: ""

, "On what day the week should be starting"
: ""

, "Default calendar strategy"
: ""

, "The calendar for new events if no container is selected"
: ""

, "Fixed Calendars"
: "Calendari fissi"

, "Calendars always selected regardless of all filter parameters."
: ""

, "Never"
: "Mai"

, "On invitation and cancellation only"
: "Su invito e recesso unicamente"

, "On time changes"
: "Nei cambiamenti di orario"

, "On all updates but attendee responses"
: "Su tutti gli aggiornamenti ma le risposte dei partecipanti"

, "On attendee responses too"
: "Troppe risposte dai partecipanti"

, "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
: "Calendari sempre selezionati indipendentemente da tutti i parametri di filtro. Un esempio di utilizzo potrebbe essere quello di forzare la visualizzazione di un determinato calendario ferie o vacanza."

, "Crop Days"
: ""

, "Crop calendar view configured start and endtime."
: ""

, "Crop Days Limit Override"
: ""

, "Allow events outside start and endtime."
: ""

, "Week View Mouse Wheel Increment"
: ""

, "Default View for Events"
: ""

, "Event Status Available"
: ""

, "Possible event status. Please note that additional event status might impact other calendar systems on export or synchronisation."
: ""

, "Confirmed"
: ""

, "Canceled"
: ""

, "Event Classes Available"
: ""

, "Possible event classes. Please note that additional event classes might impact other calendar systems on export or synchronisation."
: ""

, "Public"
: ""

, "Confidential"
: ""

, "Event Transparencies Available"
: ""

, "Possible event transparencies. Please note that additional event transparencies might impact other calendar systems on export or synchronisation."
: ""

, "Transparent"
: ""

, "Opaque"
: ""

, "Attendee Status Available"
: "Stato Partecipante Disponibile"

, "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
: ""

, "No response"
: "Nessuna risposta"

, "Accepted"
: "Accettato"

, "Declined"
: "Respinto"

, "Attendee Roles Available"
: "Ruoli Partecipante disponibili"

, "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
: ""

, "Required"
: "Richiesto"

, "Optional"
: "Opzionale"

, "Organizer has implicit edit grant"
: ""

, "Resource Types Available"
: ""

, "Possible resource types. Please note that additional free/busy types might impact other calendar systems on export or synchronisation."
: ""

, "Room"
: ""

, "Board"
: ""

, "Cable"
: ""

, "Car"
: ""

, "Coffee"
: ""

, "Homeoffice"
: ""

, "Lamp"
: ""

, "Laptop"
: ""

, "Material"
: ""

, "Projector"
: ""

, "Travel"
: ""

, "Free/Busy Types Available"
: ""

, "Possible free/busy types. Please note that additional free/busy types might impact other calendar systems on export or synchronisation."
: ""

, "Free"
: ""

, "Busy"
: ""

, "Filter timeslot for CalDAV events"
: ""

, "For how long in the past (in months) the events should be synchronized."
: ""

, "Filter timeslot for CalDAV events with SyncToken"
: ""

, "Timeslot for event notifications"
: ""

, "For how long in the past (in weeks) event notifications should be sent."
: ""

, "Default filter period (from) for events fetched via JSON API"
: ""

, "For how long in the past (in months) the events should be fetched."
: ""

, "Default filter period (until) for events fetched via JSON API"
: ""

, "For how long in the future (in months) the events should be fetched."
: ""

, "Disable iMIP for external organizers"
: ""

, "Disable notification for external organizers"
: ""

, "(CalDAV) Skip double events from personal or shared calendar"
: ""

, "(CalDAV) Skip double events from personal or shared calendar (\"personal\" > Skip events from personal calendar or \"shared\" > Skip events from shared calendar)"
: ""

, "Send notifications to every user with edit permissions of the added resources"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Calendar Application."
: ""

, "Calendar Split View"
: ""

, "Split day and week views by attendee"
: ""

, "Calendar Year View"
: ""

, "Adds year view to Calendar"
: ""

, "Calendar Extended Context Menu Actions"
: ""

, "Adds extended actions to event context menus"
: ""

, "Color Events By"
: ""

, "Choose event color by different criteria"
: ""

, "Recur Events Except"
: ""

, "Recur Events except on certain dates"
: ""

, "Activate Poll for Events"
: ""

, "Create alternative Events and let users as well as externals vote for the best option."
: ""

, "Lead Notification Confirmation"
: ""

, "Send Tentative Notifications"
: ""

, "Send notifications to event organiziers of events that are tentative certain days before event is due"
: ""

, "Enabled"
: ""

, "Days Before Due Date"
: ""

, "How many days before the events due date to start send notifications."
: ""

, "Additional Filter"
: ""

, "Additional filter to limit events notifications should be send for."
: ""

, "Mute Event Notifications for Polls"
: ""

, "Do not send invitations notifications for alternative events in an active poll."
: ""

, "GTCs for polls"
: ""

, "Freebusy Info"
: ""

, "What data the freebusy grant reveals"
: ""

, "only date & time"
: ""

, "and organizer"
: ""

, "and resources"
: ""

, "and calendar"
: ""

, "and other attendees"
: ""

, "Search Attenders Additional Filters"
: ""

, "User Additional Filters"
: ""

, "Group Additional Filters"
: ""

, "Resource Additional Filters"
: ""

, "Assign organizer meeting status on editGrant"
: ""

, "%s's personal calendar"
: "calendario personale di %s"

, "Failed"
: ""

, "The right Resource Admin must be set once."
: ""

, "Different Calendar"
: ""

, "Exdate container move are not allowed"
: ""

, "Invalid URL given"
: ""

, "The URL you used is invalid. Please use a valid one!"
: ""

, "Calendars to export"
: ""

, "Export target"
: ""

, "VCalendar/ICS"
: ""

, "Export visible events to ics file"
: ""

, "Excel overview"
: ""

, "Word event sheet"
: ""

, "Export Events as Calendar Sheet"
: ""

, "VCalendar Report"
: ""

, "Export multiple calendars to ics files"
: ""

, "OpenDocument all data"
: ""

, "Export event data into ods spreadsheet"
: ""

, "Word details"
: ""

, "Excel all data"
: ""

, "Shared Calendar CSV"
: ""

, "Resource CSV"
: ""

, "You can not have more than one grants filter"
: ""

, "Import iCal-files"
: ""

, "unknown"
: "sconosciuto"

, "This contact has been automatically added by the system as an event attender"
: "Questo contatto è stato automaticamente aggiunto dal sistema come partecipante dell'evento"

, "The email address has been shortened:"
: ""

, "Every %s day"
: ""

, "Every %s week on"
: ""

, "Weekly on"
: ""

, "and"
: ""

, "Every %1$s month on the %2$s %3$s"
: ""

, "Monthly every %1$s %2$s"
: ""

, "Every %1$s month on the %2$s"
: ""

, "Monthly on the %1$s"
: ""

, "Yearly every %1$s %2$s of %3$s"
: ""

, "Yearly on the %1$s of %2$s"
: ""

, "second to last"
: ""

, "fifth"
: ""

, "st"
: ""

, "nd"
: ""

, "rd"
: ""

, "th"
: ""

, "Start"
: "Inizio"

, "Priority"
: "Priorità"

, "Url"
: "Url"

, "Recurrance rule"
: "Regola ricorrente"

, "Is all day event"
: "E' un evento che dura tutto il giorno"

, "Organizer timezone"
: "Fuso orario organizzatore"

, "Locked"
: ""

, "Closed"
: ""

, "Alarm for event \"%1$s\" at %2$s"
: "Allarme per evento \"%1$s\" a %2$s"

, "Event invitation \"%1$s\" at %2$s"
: "Evento invito \"%1$s\" a %2$s"

, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
: ""

, "Event \"%1$s\" at %2$s has been canceled"
: "L'evento \"%1$s\" al %2$s è stato cancellato"

, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
: "L'evento \"%1$s\" è stato riprogrammato dal %2$s al %3$s"

, "Event \"%1$s\" at %2$s has been updated"
: "L'evento \"%1$s\" a %2$s è stato aggiornato"

, "%1$s accepted event \"%2$s\" at %3$s"
: "%1$s ha accettato \"%2$s\" a %3$s"

, "%1$s declined event \"%2$s\" at %3$s"
: "%1$s ha declinato l'evento \"%2$s\" a %3$s"

, "Tentative response from %1$s for event \"%2$s\" at %3$s"
: "Risposta provvisoria da %1$s per l'evento \"%2$s\" a %3$s"

, "No response from %1$s for event \"%2$s\" at %3$s"
: "Nessuna risposta da %1$s per l'evento \"%2$s\" a %3$s"

, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
: ""

, "Attendee changes for event \"%1$s\" at %2$s"
: "Il partecipanete ha cambiato per l'evento \"%1$s\" a %2$s"

, "Tentative event notification for event \"%1$s\" at %2$s"
: ""

, "Unknown action"
: ""

, "Resource Management"
: ""

, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
: ""

, "Polls for recurring events are not supported"
: ""

, "This contact has been automatically added by the system as a poll attendee"
: ""

, "Attendance Confirmation for Poll \"%1$s\""
: ""

, "%1$s is scheduled for %2$s"
: ""

, "The poll \"%1$s\" has been closed."
: ""

, "The definite event is scheduled for \"%1$s\""
: ""

, "You can review the poll results here:"
: ""

, "Thank you for attendening the poll \"%1$s\""
: ""

, "To review or edit your status please use your personal link:"
: ""

, "Updates"
: "Aggiornamenti"

, "This is an event series exception."
: ""

, "%1$s changed from \"%2$s\" to \"%3$s\""
: "%1$s cambiato da \"%2$s\" a \"%3$s\""

, "%1$s has been invited"
: "%1$s è stato invitato"

, "%1$s has been removed"
: "%1$s è stato rimosso"

, "%1$s accepted invitation"
: "%1$s ha accettato l'invito"

, "%1$s declined invitation"
: "%1$s ha declinato l'invito"

, "Tentative response from %1$s"
: "Risposta provvisoria da %1$s"

, "No response from %1$s"
: "Nessuna risposta da %1$s"

, "\"%2$s\" response from %1$s"
: "\"%2$s\" risposta da %1$s"

, "Link"
: ""

, "Event details"
: "Dettagli Evento"

, "All events I attend"
: "Tutti gli eventi a cui partecipo"

, "Awaiting response"
: "In attesa di risposta"

, "Events I have not yet responded to"
: "Eventi a cui non ho ancora risposto"

, "Declined events"
: "Eventi declinati"

, "Events I have declined"
: "Eventi che ho rifiutato"

, "I'm organizer"
: "Sono organizzatore"

, "Events I'm the organizer of"
: "Eventi di cui sono l'organizzatore"

, "manage shared calendars"
: "gestisci calendari condivisi"

, "Create new shared calendars"
: "Crea un nuovo calendario condiviso"

, "manage shared calendars favorites"
: "gestisci calendari condivisi preferiti"

, "Create or update shared calendars favorites"
: "Crea o aggiorna calendari condivisi preferiti"

, "manage resources"
: "gestisci risorse"

, "All Rights to administrate resources"
: "Tutti i diritti per amministrare le risorse"

, "Account"
: ""

, "Exporttime"
: ""

, "First name, ĺast name"
: ""

, "E-Mail address"
: ""

, "Please wait..."
: ""

, "General terms and conditions"
: ""

, "0009326B"
: ""

, "20"
: ""

, "00B359B9"
: ""

, "00997199"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "Poll"
: ""

, "Calendar"
: "Calendario"

, "Do you really want to delete this event?"
: "Vuoi veramente cancellare questo evento?"

, "Resource Grant"
: ""

, "Event"
: "Evento"

, "Attender"
: "Partecipante"

, "Resource"
: "Risorsa"

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
